@@ -1,4 +1,4 @@
-#[cfg(any(debug_assertions, test))]
+#[cfg(debug_assertions)]
 mod cell {
 	use atomic_refcell::{AtomicRefCell, AtomicRef, AtomicRefMut};
 
@@ -35,10 +35,18 @@ mod cell {
 		pub(crate) fn get_mut(&'static self) -> SinglytonRefMut<T> {
 			self.0.borrow_mut()
 		}
+
+		pub(crate) unsafe fn get_unchecked(&'static self) -> &'static T {
+			&*self.0.as_ptr()
+		}
+
+		pub(crate) unsafe fn get_mut_unchecked(&'static self) -> &'static mut T {
+			&mut *self.0.as_ptr()
+		}
 	}
 }
 
-#[cfg(not(any(debug_assertions, test)))]
+#[cfg(not(debug_assertions))]
 mod cell {
 	use core::cell::UnsafeCell;
 
@@ -75,6 +83,14 @@ mod cell {
 		pub(crate) fn get_mut(&self) -> &mut T {
 			unsafe { &mut *self.0.get() }
 		}
+
+		pub(crate) unsafe fn get_unchecked(&'static self) -> &'static T {
+			self.get()
+		}
+
+		pub(crate) unsafe fn get_mut_unchecked(&'static self) -> &'static mut T {
+			self.get_mut()
+		}
 	}
 }
 
